[Sciviews-commits] r214 - in pkg: svDialogs svDialogs/R svIDE svIDE/R svIDE/man svSocket/man

noreply at r-forge.r-project.org noreply at r-forge.r-project.org
Mon Oct 26 07:16:14 CET 2009


Author: phgrosjean
Date: 2009-10-26 07:16:13 +0100 (Mon, 26 Oct 2009)
New Revision: 214

Modified:
   pkg/svDialogs/DESCRIPTION
   pkg/svDialogs/NEWS
   pkg/svDialogs/R/flexibleDlg.R
   pkg/svIDE/DESCRIPTION
   pkg/svIDE/NEWS
   pkg/svIDE/R/guiDDEInstall.R
   pkg/svIDE/man/guiDDEInstall.Rd
   pkg/svSocket/man/processSocket.Rd
Log:
Small corrections in svDialogs, svIDE & svSocket

Modified: pkg/svDialogs/DESCRIPTION
===================================================================
--- pkg/svDialogs/DESCRIPTION	2009-10-17 13:10:25 UTC (rev 213)
+++ pkg/svDialogs/DESCRIPTION	2009-10-26 06:16:13 UTC (rev 214)
@@ -5,8 +5,8 @@
 Imports: tcltk, svMisc
 Description: Rapidly construct dialog boxes for your GUI, including an automatic
   function assistant
-Version: 0.9-41
-Date: 2009-09-28
+Version: 0.9-42
+Date: 2009-10-26
 Author: Philippe Grosjean
 Maintainer: Philippe Grosjean <phgrosjean at sciviews.org>
 License: GPL (>= 2)

Modified: pkg/svDialogs/NEWS
===================================================================
--- pkg/svDialogs/NEWS	2009-10-17 13:10:25 UTC (rev 213)
+++ pkg/svDialogs/NEWS	2009-10-26 06:16:13 UTC (rev 214)
@@ -1,5 +1,10 @@
 = svDialogs News
 
+== Changes in svDialogs 0.9-42
+
+* guiDlgFun() is adapted to the new help system provided in R 2.10.
+
+
 == Changes in svDialogs 0.9-41
 
 * When the path contained spaces, guiDlgOpen() and guiDlgSave() returned them in

Modified: pkg/svDialogs/R/flexibleDlg.R
===================================================================
--- pkg/svIDE/DESCRIPTION	2009-10-17 13:10:25 UTC (rev 213)
+++ pkg/svIDE/DESCRIPTION	2009-10-26 06:16:13 UTC (rev 214)
@@ -4,8 +4,8 @@
 Depends: R (>= 2.6.0)
 Imports: utils, tcltk, svMisc
 Description: Function for the GUI API to interact with external IDE/code editors
-Version: 0.9-46
-Date: 2009-08-10
+Version: 0.9-47
+Date: 2009-10-26
 Author: Philippe Grosjean
 Maintainer: Philippe Grosjean <phgrosjean at sciviews.org>
 License: GPL (>= 2)

Modified: pkg/svIDE/NEWS
===================================================================
--- pkg/svIDE/NEWS	2009-10-17 13:10:25 UTC (rev 213)
+++ pkg/svIDE/NEWS	2009-10-26 06:16:13 UTC (rev 214)
@@ -1,5 +1,12 @@
 = svIDE News
 
+== Changes in svIDE 0.9-47
+
+* guiComplete now does not have a givetype argument any more. Extra information
+  is now always returned. This follows changes made in the original Complete()
+  function in svMisc that is called by guiComplete().
+  
+
 == Changes in svIDE 0.9-46
 
 * the trXXX() functions for Tinn-R are eliminated (they are now in their own

Modified: pkg/svIDE/R/guiDDEInstall.R
===================================================================
--- pkg/svIDE/R/guiDDEInstall.R	2009-10-17 13:10:25 UTC (rev 213)
+++ pkg/svIDE/R/guiDDEInstall.R	2009-10-26 06:16:13 UTC (rev 214)
@@ -37,7 +37,7 @@
 }
 
 "guiComplete" <-
-function (code, file = NULL, givetype = FALSE, sep = "|")
+function (code, file = NULL, sep = "|")
 {
     # This is an interfacte to Complete for external programs
     # Clear ::SciViewsR_Complete
@@ -45,11 +45,10 @@
 
     # Using a callback, all args are strings => convert
     if (length(file) == 0 || file == "" || file == "NULL") file <- NULL
-    givetype <- as.logical(givetype[1])
     sep = sep[1]
 
     # Get the completion list
-	clist <- Complete(code, givetype = givetype, sep = sep)
+	clist <- Complete(code, sep = sep)
 
 	# Copy the result to a Tcl variable
     .Tcl(paste("set ::SciViewsR_Complete {", clist, "}", sep = ""))
@@ -79,8 +78,9 @@
 		return("DDE not installed: this is not Windows!")
 	if (!capabilities("tcltk"))
 		return("DDE not installed: this version of R cannot use Tcl/Tk!")
-    if (!require(tcltk))
-		return("DDE not installed: impossible to load tcltk package!")
+    # Not needed, since tcltk is now imported in NAMESPACE!
+	#if (!require(tcltk))
+	#	return("DDE not installed: impossible to load tcltk package!")
 	tclRequire("dde", warn = TRUE)
 	# Should be installed by default with the tcltk package under Windows
 
@@ -111,7 +111,7 @@
 
     # guiComplete()... Take care: must be adapted if you change guiComplete()!
     res <- .Tcl.args(guiComplete)
-    .Tcl(paste("proc guiComplete {code {file \"\"} {givetype FALSE}",
+    .Tcl(paste("proc guiComplete {code {file \"\"}",
 		" {sep |} }", gsub("%", "$", res), sep = ""))
 
     # Done

Modified: pkg/svIDE/man/guiDDEInstall.Rd
===================================================================
--- pkg/svIDE/man/guiDDEInstall.Rd	2009-10-17 13:10:25 UTC (rev 213)
+++ pkg/svIDE/man/guiDDEInstall.Rd	2009-10-26 06:16:13 UTC (rev 214)
@@ -11,7 +11,7 @@
 \usage{
 guiDDEInstall()
 guiCallTip(code, file = NULL, onlyargs = FALSE, width = 60, location = FALSE)
-guiComplete(code, file = NULL, givetype = FALSE, sep = "|")
+guiComplete(code, file = NULL, sep = "|")
 }
 
 \arguments{
@@ -22,8 +22,6 @@
   \item{width}{ Reformat the calltip to with (use 0 for not reformatting it) }
   \item{location}{ If \code{TRUE} then the location (in which package the
     function resides) is appended to the calltip between square brackets }
-  \item{givetype}{ Return also the type of each object in the completion list (possibly
-    to use set a different icon in the list displayed by the external program) }
   \item{sep}{ The separator to use between the item and its type in the list }
 }
 

Modified: pkg/svSocket/man/processSocket.Rd
===================================================================
--- pkg/svSocket/man/processSocket.Rd	2009-10-17 13:10:25 UTC (rev 213)
+++ pkg/svSocket/man/processSocket.Rd	2009-10-26 06:16:13 UTC (rev 214)
@@ -73,7 +73,7 @@
 \author{Philippe Grosjean (\email{phgrosjean at sciviews.org})}
 
 \seealso{ \code{\link{startSocketServer}}, \code{\link{sendSocketClients}},
-  \code{\link{svTaskCallbackManager}}, \code{\link[svMisc]{parSocket}},
+  \code{\link{svTaskCallbackManager}}, \code{\link{parSocket}},
   \code{\link[svMisc]{Parse}}, \code{\link[svMisc]{captureAll}} }
 
 \examples{



More information about the Sciviews-commits mailing list
--- pkg/svDialogs/R/flexibleDlg.R	2009-10-17 13:10:25 UTC (rev 213)
+++ pkg/svDialogs/R/flexibleDlg.R	2009-10-26 06:16:13 UTC (rev 214)
@@ -283,8 +283,18 @@
     #### TO DO: use syntax for call arg by position!
     # Construct a default template for this function
     if (isHelp(fun)["help"]) {
-        Help <- paste("browseURL('", help(fun, htmlhelp = TRUE), "')", sep = "")
-        # Or simply use: paste("help('", fun, "')", sep = "") to use default help system
+        hlp <- function (...) help(...) # To avoid warning on R CMD check!
+        # help() function is changed in R 2.10!
+        if (exists("getRversion", mode = "function") &&
+            getRversion() >= '2.10') {
+            Help <- paste("browseURL('", hlp(fun, help_type = "html"), "')",
+                sep = "")
+        } else { # This is R <= 2.9.x
+            Help <- paste("browseURL('", hlp(fun, htmlhelp = TRUE), "')",
+                sep = "")
+            # Or simply use: paste("help('", fun, "')", sep = "")
+            # to use default help system
+        }
     } else Help <- NULL
     Tpl <- list(list(fun = fun, var = var, title = "Function assistant",
         message = NULL, help = Help, sep = NULL, width = width,

Modified: pkg/svIDE/DESCRIPTION
===================================================================